@@ -1,20 +1,12 @@
-
-error_oldUniqueByKey = "The deprecated option 'datatable.old.unique.by.key' is being used. Please stop using it and pass 'by=key(DT)' instead for clarity. For more information please search the NEWS file for this option."
-# remove this option in June 2020 (see note 10 from 1.12.4 in May 2019 which said one year from then )
-
 duplicated.data.table = function(x, incomparables=FALSE, fromLast=FALSE, by=seq_along(x), ...) {
   if (!cedta()) return(NextMethod("duplicated")) #nocov
   if (!identical(incomparables, FALSE)) {
     .NotYetUsed("incomparables != FALSE")
   }
-  if (missing(by) && isTRUE(getOption("datatable.old.unique.by.key"))) {  #1284
-    by = key(x)
-    stop(error_oldUniqueByKey)
-  }
-  if (nrow(x) == 0L || ncol(x) == 0L) return(logical(0L)) # fix for bug #5582
+  if (nrow(x) == 0L || ncol(x) == 0L) return(logical(0L)) # fix for bug #28
   if (is.na(fromLast) || !is.logical(fromLast)) stop("'fromLast' must be TRUE or FALSE")
   query = .duplicated.helper(x, by)
-  # fix for bug #5405 - unique on null data table returns error (because of 'forderv')
+  # fix for bug #44 - unique on null data table returns error (because of 'forderv')
   # however, in this case we can bypass having to go to forderv at all.
   if (!length(query$by)) return(logical(0L))
 
@@ -39,10 +31,6 @@ unique.data.table = function(x, incomparables=FALSE, fromLast=FALSE, by=seq_alon
     .NotYetUsed("incomparables != FALSE")
   }
   if (nrow(x) <= 1L) return(x)
-  if (missing(by) && isTRUE(getOption("datatable.old.unique.by.key"))) {
-    by = key(x)
-    stop(error_oldUniqueByKey)
-  }
   o = forderv(x, by=by, sort=FALSE, retGrp=TRUE)
   # if by=key(x), forderv tests for orderedness within it quickly and will short-circuit
   # there isn't any need in unique() to call uniqlist like duplicated does; uniqlist returns a new nrow(x) vector anyway and isn't
@@ -93,16 +81,12 @@ unique.data.table = function(x, incomparables=FALSE, fromLast=FALSE, by=seq_alon
   list(use.keyprefix=use.keyprefix, by=names(x)[cols])
 }
 
-# FR #5172 anyDuplicated.data.table
+# FR #350 anyDuplicated.data.table
 # Note that base's anyDuplicated is faster than any(duplicated(.)) (for vectors) - for data.frames it still pastes before calling duplicated
 # In that sense, this anyDuplicated is *not* the same as base's - meaning it's not a different implementation
 # This is just a wrapper. That being said, it should be incredibly fast on data.tables (due to data.table's fast forder)
 anyDuplicated.data.table = function(x, incomparables=FALSE, fromLast=FALSE, by=seq_along(x), ...) {
   if (!cedta()) return(NextMethod("anyDuplicated")) # nocov
-  if (missing(by) && isTRUE(getOption("datatable.old.unique.by.key"))) {
-    by = key(x)
-    stop(error_oldUniqueByKey)
-  }
   dups = duplicated(x, incomparables, fromLast, by, ...)
   if (fromLast) idx = tail(which(dups), 1L) else idx = head(which(dups), 1L)
   if (!length(idx)) idx=0L
@@ -114,10 +98,6 @@ anyDuplicated.data.table = function(x, incomparables=FALSE, fromLast=FALSE, by=s
 # we really mean `.SD` - used in a grouping operation
 # TODO: optimise uniqueN further with GForce.
 uniqueN = function(x, by = if (is.list(x)) seq_along(x) else NULL, na.rm=FALSE) { # na.rm, #1455
-  if (missing(by) && is.data.table(x) && isTRUE(getOption("datatable.old.unique.by.key"))) {
-    by = key(x)
-    stop(error_oldUniqueByKey)
-  }
   if (is.null(x)) return(0L)
   if (!is.atomic(x) && !is.data.frame(x))
     stop("x must be an atomic vector or data.frames/data.tables")
