@@ -12,7 +12,7 @@ frankv = function(x, cols=seq_along(x), order=1L, na.last=TRUE, ties.method=c("a
     .Call(Csetlistelt, xx, 1L, x)
     xx
   }
-  if (is.atomic(x)) {
+  if (is.atomic(x) || is.null(x)) {
     if (!missing(cols) && !is.null(cols))
       stop("x is a single vector, non-NULL 'cols' doesn't make sense")
     cols = 1L
